@@ -660,7 +660,6 @@ class GenericOwner(Buddy):
         self._ps = ps
         self._server = kwargs.pop("server", None)
         self._key_hash = kwargs.pop("key_hash", None)
-        self._registered = kwargs.pop("registered", False)
 
         #: Telepathy plugin -> dict { activity ID -> room handle }
         self._activities_by_connection = {}
@@ -907,15 +906,11 @@ class GenericOwner(Buddy):
                 if tp.status == CONNECTION_STATUS_CONNECTED:
                     self._set_self_olpc_properties(tp)
 
-    def _ip4_address_changed_cb(self, monitor, address):
+    def _ip4_address_changed_cb(self, monitor, address, iface):
         """Handle IPv4 address change, set property to generate event"""
         props = {_PROP_IP4_ADDRESS: address}
         self.set_properties(props)
 
-    def get_registered(self):
-        """Retrieve whether owner has registered with presence server"""
-        return self._registered
-
     def get_server(self):
         """Retrieve XMPP server hostname (used by the server plugin)"""
         return self._server
@@ -926,10 +921,6 @@ class GenericOwner(Buddy):
         """
         return self._key_hash
 
-    def set_registered(self, registered):
-        """Customisation point: handle the registration of the owner"""
-        raise RuntimeError("Subclasses must implement")
-
     def update_avatar(self, tp, new_avatar_token, icon=None, mime_type=None):
         # This should never get called because Owner avatar changes are
         # driven by the Sugar shell, but just in case:
@@ -963,7 +954,6 @@ class ShellOwner(GenericOwner):
         profile = get_profile()
 
         server = profile.jabber_server
-        registered = profile.jabber_registered
         key_hash = profile.privkey_hash
         key = profile.pubkey
         nick = profile.nick_name
@@ -977,7 +967,7 @@ class ShellOwner(GenericOwner):
         GenericOwner.__init__(self, ps, bus,
                 'keyid/' + psutils.pubkey_to_keyid(key),
                 key=key, nick=nick, color=color, icon=icon, server=server,
-                key_hash=key_hash, registered=registered)
+                key_hash=key_hash)
 
         # Ask to get notifications on Owner object property changes in the
         # shell. If it's not currently running, no problem - we'll get the
@@ -994,13 +984,6 @@ class ShellOwner(GenericOwner):
         # we already know our own nick, color, key
         self._awaiting = None
 
-    def set_registered(self, value):
-        """Handle notification that we have been registered"""
-        if value:
-            profile = get_profile()
-            profile.jabber_registered = True
-            profile.save()
-
     def _icon_changed_cb(self, icon):
         """Handle icon change, set property to generate event"""
         icon = str(icon)
